wordcloud\_map()
----------------

.. currentmodule:: wordcloud_mapper
.. autofunction:: wordcloud_map


resize\_map()
------------------------------------

.. currentmodule:: wordcloud_mapper
.. autofunction:: resize_map


load\_companies()
----------------------------------------

.. currentmodule:: wordcloud_mapper
.. autofunction:: load_companies


calc\_tfidf()
----------------------------------------

.. currentmodule:: wordcloud_mapper
.. autofunction:: calc_tfidf
